@@ -21,8 +21,8 @@ impl ROMol {
         ro_mol_ffi::mol_to_smiles(self.ptr.clone())
     }
 
-    pub fn to_rw_mol(self, quick_copy: bool, conf_id: i32) -> RWMol {
-        let ptr = rdkit_sys::rw_mol_ffi::rw_mol_from_ro_mol(self.ptr, quick_copy, conf_id);
+    pub fn to_rw_mol(&self, quick_copy: bool, conf_id: i32) -> RWMol {
+        let ptr = rdkit_sys::rw_mol_ffi::rw_mol_from_ro_mol(self.ptr.clone(), quick_copy, conf_id);
         RWMol {
             ptr
         }
@@ -40,3 +40,11 @@ impl Debug for ROMol {
         f.debug_struct("Molecule").field("ptr", &smile).finish()
     }
 }
+
+impl Clone for ROMol {
+    fn clone(&self) -> Self {
+        ROMol {
+            ptr: rdkit_sys::ro_mol_ffi::copy_mol(self.ptr.clone())
+        }
+    }
+}
\ No newline at end of file
